isConnectable property
Whether connections can be made to/from this port.
When false, the port is displayed but cannot participate in new connections. Existing connections are not affected.
Implementation
final bool isConnectable;
Whether connections can be made to/from this port.
When false, the port is displayed but cannot participate in new connections. Existing connections are not affected.
final bool isConnectable;