showConnectionLines property
Whether to show connection lines between nodes.
When false, connections are not rendered at all, which significantly
improves performance when viewing large graphs from a distance.
Implementation
final bool showConnectionLines;